@@ -1,15 +1,26 @@
-use cosmwasm_std::{Binary, StdError, StdResult, Uint128};
-use cw20::{Cw20Coin, Expiration, MinterResponse};
+use cosmwasm_std::{StdError, StdResult, Uint128};
+use cw20::{Cw20Coin, Logo, MinterResponse};
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 
-#[derive(Serialize, Deserialize, JsonSchema)]
+pub use cw20::Cw20ExecuteMsg as ExecuteMsg;
+
+#[derive(Serialize, Deserialize, JsonSchema, Debug, Clone, PartialEq)]
+pub struct InstantiateMarketingInfo {
+    pub project: Option<String>,
+    pub description: Option<String>,
+    pub marketing: Option<String>,
+    pub logo: Option<Logo>,
+}
+
+#[derive(Serialize, Deserialize, JsonSchema, Debug, Clone, PartialEq)]
 pub struct InstantiateMsg {
     pub name: String,
     pub symbol: String,
     pub decimals: u8,
     pub initial_balances: Vec<Cw20Coin>,
     pub mint: Option<MinterResponse>,
+    pub marketing: Option<InstantiateMarketingInfo>,
 }
 
 impl InstantiateMsg {
@@ -21,12 +32,12 @@ impl InstantiateMsg {
         // Check name, symbol, decimals
         if !is_valid_name(&self.name) {
             return Err(StdError::generic_err(
-                "Name is not in the expected format (3-30 UTF-8 bytes)",
+                "Name is not in the expected format (3-50 UTF-8 bytes)",
             ));
         }
         if !is_valid_symbol(&self.symbol) {
             return Err(StdError::generic_err(
-                "Ticker symbol is not in expected format [A-Z]{3,6}",
+                "Ticker symbol is not in expected format [a-zA-Z\\-]{3,12}",
             ));
         }
         if self.decimals > 18 {
@@ -38,7 +49,7 @@ impl InstantiateMsg {
 
 fn is_valid_name(name: &str) -> bool {
     let bytes = name.as_bytes();
-    if bytes.len() < 3 || bytes.len() > 30 {
+    if bytes.len() < 3 || bytes.len() > 50 {
         return false;
     }
     true
@@ -46,69 +57,17 @@ fn is_valid_name(name: &str) -> bool {
 
 fn is_valid_symbol(symbol: &str) -> bool {
     let bytes = symbol.as_bytes();
-    if bytes.len() < 3 || bytes.len() > 6 {
+    if bytes.len() < 3 || bytes.len() > 12 {
         return false;
     }
     for byte in bytes.iter() {
-        if *byte < 65 || *byte > 90 {
+        if (*byte != 45) && (*byte < 65 || *byte > 90) && (*byte < 97 || *byte > 122) {
             return false;
         }
     }
     true
 }
 
-#[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
-#[serde(rename_all = "snake_case")]
-pub enum ExecuteMsg {
-    /// Transfer is a base message to move tokens to another account without triggering actions
-    Transfer { recipient: String, amount: Uint128 },
-    /// Burn is a base message to destroy tokens forever
-    Burn { amount: Uint128 },
-    /// Send is a base message to transfer tokens to a contract and trigger an action
-    /// on the receiving contract.
-    Send {
-        contract: String,
-        amount: Uint128,
-        msg: Binary,
-    },
-    /// Only with the "mintable" extension. If authorized, creates amount new tokens
-    /// and adds to the recipient balance.
-    Mint { recipient: String, amount: Uint128 },
-    /// Only with "approval" extension. Allows spender to access an additional amount tokens
-    /// from the owner's (env.sender) account. If expires is Some(), overwrites current allowance
-    /// expiration with this one.
-    IncreaseAllowance {
-        spender: String,
-        amount: Uint128,
-        expires: Option<Expiration>,
-    },
-    /// Only with "approval" extension. Lowers the spender's access of tokens
-    /// from the owner's (env.sender) account by amount. If expires is Some(), overwrites current
-    /// allowance expiration with this one.
-    DecreaseAllowance {
-        spender: String,
-        amount: Uint128,
-        expires: Option<Expiration>,
-    },
-    /// Only with "approval" extension. Transfers amount tokens from owner -> recipient
-    /// if `env.sender` has sufficient pre-approval.
-    TransferFrom {
-        owner: String,
-        recipient: String,
-        amount: Uint128,
-    },
-    /// Only with "approval" extension. Sends amount tokens from owner -> contract
-    /// if `env.sender` has sufficient pre-approval.
-    SendFrom {
-        owner: String,
-        contract: String,
-        amount: Uint128,
-        msg: Binary,
-    },
-    /// Only with "approval" extension. Destroys tokens forever
-    BurnFrom { owner: String, amount: Uint128 },
-}
-
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 #[serde(rename_all = "snake_case")]
 pub enum QueryMsg {
@@ -119,7 +78,7 @@ pub enum QueryMsg {
     /// Return type: TokenInfoResponse.
     TokenInfo {},
     /// Only with "mintable" extension.
-    /// Returns who can mint and how much.
+    /// Returns who can mint and the hard cap on maximum tokens after minting.
     /// Return type: MinterResponse.
     Minter {},
     /// Only with "allowance" extension.
@@ -141,4 +100,14 @@ pub enum QueryMsg {
         start_after: Option<String>,
         limit: Option<u32>,
     },
+    /// Only with "marketing" extension
+    /// Returns more metadata on the contract to display in the client:
+    /// - description, logo, project url, etc.
+    /// Return type: MarketingInfoResponse
+    MarketingInfo {},
+    /// Only with "marketing" extension
+    /// Downloads the mbeded logo data (if stored on chain). Errors if no logo data ftored for this
+    /// contract.
+    /// Return type: DownloadLogoResponse.
+    DownloadLogo {},
 }
